@@ -3,9 +3,7 @@ from pythonit_toolkit.pastaporto.exceptions import InvalidPastaportoError
 from starlette.authentication import AuthenticationBackend, AuthenticationError
 from starlette.responses import JSONResponse
 from starlette.routing import request_response
-
-PASTAPORTO_X_HEADER = "x-pastaporto"
-
+from pythonit_toolkit.headers import PASTAPORTO_X_HEADER
 
 def on_auth_error(request: request_response, exc: Exception):
     return JSONResponse({"errors": [{"message": str(exc)}]}, status_code=401)
